# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ansys_kernel.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ansys_kernel.proto',
  package='ansys.api.kernel.v0',
  syntax='proto3',
  serialized_options=_b('\252\002\023Ansys.Api.Kernel.V0'),
  serialized_pb=_b('\n\x12\x61nsys_kernel.proto\x12\x13\x61nsys.api.kernel.v0\"\x0e\n\x0c\x45mptyRequest\"\x0f\n\rEmptyResponse\")\n\x0b\x43trlRequest\x12\x0c\n\x04\x63trl\x18\x01 \x01(\t\x12\x0c\n\x04opt1\x18\x02 \x01(\t\"0\n\x0c\x43trlResponse\x12\x10\n\x08response\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\x05\"5\n\rStreamRequest\x12\x12\n\nchunk_size\x18\x01 \x01(\x05\x12\x10\n\x08rec_name\x18\x02 \x01(\t\"}\n\x05\x43hunk\x12\x12\n\narray_name\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x32\n\nvalue_type\x18\x03 \x01(\x0e\x32\x1e.ansys.api.kernel.v0.ValueType\x12\r\n\x05shape\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x03\"3\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\x05\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\t\n\x01z\x18\x04 \x01(\x01\"\xab\x02\n\x06Matrix\x12\x0c\n\x04nrow\x18\x01 \x01(\x05\x12\x0c\n\x04ncol\x18\x02 \x01(\x05\x12-\n\x05vtype\x18\x03 \x01(\x0e\x32\x1e.ansys.api.kernel.v0.ValueType\x12:\n\x07Storage\x18\x04 \x01(\x0e\x32).ansys.api.kernel.v0.Matrix.StorageOption\x12\x34\n\x04side\x18\x05 \x01(\x0e\x32&.ansys.api.kernel.v0.Matrix.SideOption\"6\n\rStorageOption\x12\t\n\x05\x44\x45NSE\x10\x00\x12\x07\n\x03SYM\x10\x01\x12\x08\n\x04\x44IAG\x10\x02\x12\x07\n\x03\x43SR\x10\x03\",\n\nSideOption\x12\t\n\x05UPPER\x10\x00\x12\t\n\x05LOWER\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\"G\n\x0b\x44\x65nseMatrix\x12(\n\x03mat\x18\x01 \x01(\x0b\x32\x1b.ansys.api.kernel.v0.Matrix\x12\x0e\n\x06values\x18\x02 \x03(\x01\"\x92\x01\n\x0cSparseMatrix\x12(\n\x03mat\x18\x01 \x01(\x0b\x32\x1b.ansys.api.kernel.v0.Matrix\x12\x0e\n\x06maxlen\x18\x02 \x01(\x05\x12\x0c\n\x04nval\x18\x03 \x01(\x03\x12\x0b\n\x03sym\x18\x04 \x01(\x08\x12\x0c\n\x04rows\x18\x05 \x03(\x03\x12\x0f\n\x07\x63olsIdx\x18\x06 \x03(\x05\x12\x0e\n\x06values\x18\x07 \x03(\x01*r\n\tValueType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\t\n\x05HYPER\x10\x02\x12\t\n\x05SHORT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\t\n\x05\x46\x43PLX\x10\x06\x12\t\n\x05\x44\x43PLX\x10\x07\x12\x08\n\x04\x43HAR\x10\x08\x42\x16\xaa\x02\x13\x41nsys.Api.Kernel.V0b\x06proto3')
)

_VALUETYPE = _descriptor.EnumDescriptor(
  name='ValueType',
  full_name='ansys.api.kernel.v0.ValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEGER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HYPER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FCPLX', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DCPLX', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHAR', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=928,
  serialized_end=1042,
)
_sym_db.RegisterEnumDescriptor(_VALUETYPE)

ValueType = enum_type_wrapper.EnumTypeWrapper(_VALUETYPE)
UNKNOWN = 0
INTEGER = 1
HYPER = 2
SHORT = 3
FLOAT = 4
DOUBLE = 5
FCPLX = 6
DCPLX = 7
CHAR = 8


_MATRIX_STORAGEOPTION = _descriptor.EnumDescriptor(
  name='StorageOption',
  full_name='ansys.api.kernel.v0.Matrix.StorageOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DENSE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYM', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIAG', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CSR', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=604,
  serialized_end=658,
)
_sym_db.RegisterEnumDescriptor(_MATRIX_STORAGEOPTION)

_MATRIX_SIDEOPTION = _descriptor.EnumDescriptor(
  name='SideOption',
  full_name='ansys.api.kernel.v0.Matrix.SideOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPPER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=660,
  serialized_end=704,
)
_sym_db.RegisterEnumDescriptor(_MATRIX_SIDEOPTION)


_EMPTYREQUEST = _descriptor.Descriptor(
  name='EmptyRequest',
  full_name='ansys.api.kernel.v0.EmptyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=57,
)


_EMPTYRESPONSE = _descriptor.Descriptor(
  name='EmptyResponse',
  full_name='ansys.api.kernel.v0.EmptyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=74,
)


_CTRLREQUEST = _descriptor.Descriptor(
  name='CtrlRequest',
  full_name='ansys.api.kernel.v0.CtrlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ctrl', full_name='ansys.api.kernel.v0.CtrlRequest.ctrl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opt1', full_name='ansys.api.kernel.v0.CtrlRequest.opt1', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=117,
)


_CTRLRESPONSE = _descriptor.Descriptor(
  name='CtrlResponse',
  full_name='ansys.api.kernel.v0.CtrlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='ansys.api.kernel.v0.CtrlResponse.response', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='ansys.api.kernel.v0.CtrlResponse.status', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=167,
)


_STREAMREQUEST = _descriptor.Descriptor(
  name='StreamRequest',
  full_name='ansys.api.kernel.v0.StreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='ansys.api.kernel.v0.StreamRequest.chunk_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rec_name', full_name='ansys.api.kernel.v0.StreamRequest.rec_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=222,
)


_CHUNK = _descriptor.Descriptor(
  name='Chunk',
  full_name='ansys.api.kernel.v0.Chunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array_name', full_name='ansys.api.kernel.v0.Chunk.array_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='ansys.api.kernel.v0.Chunk.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='ansys.api.kernel.v0.Chunk.value_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='ansys.api.kernel.v0.Chunk.shape', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='ansys.api.kernel.v0.Chunk.size', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=349,
)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='ansys.api.kernel.v0.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ansys.api.kernel.v0.Node.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x', full_name='ansys.api.kernel.v0.Node.x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='ansys.api.kernel.v0.Node.y', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='ansys.api.kernel.v0.Node.z', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=402,
)


_MATRIX = _descriptor.Descriptor(
  name='Matrix',
  full_name='ansys.api.kernel.v0.Matrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nrow', full_name='ansys.api.kernel.v0.Matrix.nrow', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ncol', full_name='ansys.api.kernel.v0.Matrix.ncol', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vtype', full_name='ansys.api.kernel.v0.Matrix.vtype', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Storage', full_name='ansys.api.kernel.v0.Matrix.Storage', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='side', full_name='ansys.api.kernel.v0.Matrix.side', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MATRIX_STORAGEOPTION,
    _MATRIX_SIDEOPTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=405,
  serialized_end=704,
)


_DENSEMATRIX = _descriptor.Descriptor(
  name='DenseMatrix',
  full_name='ansys.api.kernel.v0.DenseMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mat', full_name='ansys.api.kernel.v0.DenseMatrix.mat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='ansys.api.kernel.v0.DenseMatrix.values', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=706,
  serialized_end=777,
)


_SPARSEMATRIX = _descriptor.Descriptor(
  name='SparseMatrix',
  full_name='ansys.api.kernel.v0.SparseMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mat', full_name='ansys.api.kernel.v0.SparseMatrix.mat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxlen', full_name='ansys.api.kernel.v0.SparseMatrix.maxlen', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nval', full_name='ansys.api.kernel.v0.SparseMatrix.nval', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sym', full_name='ansys.api.kernel.v0.SparseMatrix.sym', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows', full_name='ansys.api.kernel.v0.SparseMatrix.rows', index=4,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='colsIdx', full_name='ansys.api.kernel.v0.SparseMatrix.colsIdx', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='ansys.api.kernel.v0.SparseMatrix.values', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=926,
)

_CHUNK.fields_by_name['value_type'].enum_type = _VALUETYPE
_MATRIX.fields_by_name['vtype'].enum_type = _VALUETYPE
_MATRIX.fields_by_name['Storage'].enum_type = _MATRIX_STORAGEOPTION
_MATRIX.fields_by_name['side'].enum_type = _MATRIX_SIDEOPTION
_MATRIX_STORAGEOPTION.containing_type = _MATRIX
_MATRIX_SIDEOPTION.containing_type = _MATRIX
_DENSEMATRIX.fields_by_name['mat'].message_type = _MATRIX
_SPARSEMATRIX.fields_by_name['mat'].message_type = _MATRIX
DESCRIPTOR.message_types_by_name['EmptyRequest'] = _EMPTYREQUEST
DESCRIPTOR.message_types_by_name['EmptyResponse'] = _EMPTYRESPONSE
DESCRIPTOR.message_types_by_name['CtrlRequest'] = _CTRLREQUEST
DESCRIPTOR.message_types_by_name['CtrlResponse'] = _CTRLRESPONSE
DESCRIPTOR.message_types_by_name['StreamRequest'] = _STREAMREQUEST
DESCRIPTOR.message_types_by_name['Chunk'] = _CHUNK
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Matrix'] = _MATRIX
DESCRIPTOR.message_types_by_name['DenseMatrix'] = _DENSEMATRIX
DESCRIPTOR.message_types_by_name['SparseMatrix'] = _SPARSEMATRIX
DESCRIPTOR.enum_types_by_name['ValueType'] = _VALUETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EmptyRequest = _reflection.GeneratedProtocolMessageType('EmptyRequest', (_message.Message,), dict(
  DESCRIPTOR = _EMPTYREQUEST,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.EmptyRequest)
  ))
_sym_db.RegisterMessage(EmptyRequest)

EmptyResponse = _reflection.GeneratedProtocolMessageType('EmptyResponse', (_message.Message,), dict(
  DESCRIPTOR = _EMPTYRESPONSE,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.EmptyResponse)
  ))
_sym_db.RegisterMessage(EmptyResponse)

CtrlRequest = _reflection.GeneratedProtocolMessageType('CtrlRequest', (_message.Message,), dict(
  DESCRIPTOR = _CTRLREQUEST,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.CtrlRequest)
  ))
_sym_db.RegisterMessage(CtrlRequest)

CtrlResponse = _reflection.GeneratedProtocolMessageType('CtrlResponse', (_message.Message,), dict(
  DESCRIPTOR = _CTRLRESPONSE,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.CtrlResponse)
  ))
_sym_db.RegisterMessage(CtrlResponse)

StreamRequest = _reflection.GeneratedProtocolMessageType('StreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _STREAMREQUEST,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.StreamRequest)
  ))
_sym_db.RegisterMessage(StreamRequest)

Chunk = _reflection.GeneratedProtocolMessageType('Chunk', (_message.Message,), dict(
  DESCRIPTOR = _CHUNK,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.Chunk)
  ))
_sym_db.RegisterMessage(Chunk)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
  DESCRIPTOR = _NODE,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.Node)
  ))
_sym_db.RegisterMessage(Node)

Matrix = _reflection.GeneratedProtocolMessageType('Matrix', (_message.Message,), dict(
  DESCRIPTOR = _MATRIX,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.Matrix)
  ))
_sym_db.RegisterMessage(Matrix)

DenseMatrix = _reflection.GeneratedProtocolMessageType('DenseMatrix', (_message.Message,), dict(
  DESCRIPTOR = _DENSEMATRIX,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.DenseMatrix)
  ))
_sym_db.RegisterMessage(DenseMatrix)

SparseMatrix = _reflection.GeneratedProtocolMessageType('SparseMatrix', (_message.Message,), dict(
  DESCRIPTOR = _SPARSEMATRIX,
  __module__ = 'ansys_kernel_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.kernel.v0.SparseMatrix)
  ))
_sym_db.RegisterMessage(SparseMatrix)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
